Module: VagrantPlugins::OrbStack

Defined in:
lib/vagrant-orbstack.rb,
lib/vagrant-orbstack/action.rb,
lib/vagrant-orbstack/config.rb,
lib/vagrant-orbstack/errors.rb,
lib/vagrant-orbstack/plugin.rb,
lib/vagrant-orbstack/version.rb,
lib/vagrant-orbstack/provider.rb,
lib/vagrant-orbstack/action/halt.rb,
lib/vagrant-orbstack/action/start.rb,
lib/vagrant-orbstack/action/create.rb,
lib/vagrant-orbstack/action/reload.rb,
lib/vagrant-orbstack/action/destroy.rb,
lib/vagrant-orbstack/action/ssh_run.rb,
lib/vagrant-orbstack/util/state_cache.rb,
lib/vagrant-orbstack/util/orbstack_cli.rb,
lib/vagrant-orbstack/util/machine_namer.rb,
lib/vagrant-orbstack/action/machine_validation.rb,
lib/vagrant-orbstack/util/ssh_readiness_checker.rb

Overview

OrbStack provider plugin namespace

Defined Under Namespace

Modules: Action, Util Classes: CommandExecutionError, CommandTimeoutError, Config, Errors, MachineNameCollisionError, OrbStackNotInstalled, OrbStackNotRunning, Plugin, Provider, SSHConnectionFailed, SSHNotReady

Constant Summary collapse

UNSET_VALUE =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

Sentinel value to distinguish "not set" from nil. Used in configuration to differentiate between explicitly set to nil versus never configured (should use default).

::Object.new.freeze
VERSION =
'0.1.1'

Class Method Summary collapse

Class Method Details

.source_rootPathname

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns the path to the source of this plugin.

Returns:

  • (Pathname)

    Root directory of the plugin source



32
33
34
# File 'lib/vagrant-orbstack.rb', line 32

def self.source_root
  @source_root ||= Pathname.new(File.join(__dir__, '..'))
end