Class: VagrantPlugins::OrbStack::Errors

Inherits:
Vagrant::Errors::VagrantError
  • Object
show all
Defined in:
lib/vagrant-orbstack/errors.rb,
lib/vagrant-orbstack/errors.rb

Overview

Reopen Errors class to add nested constants for namespaced access This allows both VagrantPlugins::OrbStack::CommandTimeoutError and VagrantPlugins::OrbStack::Errors::CommandTimeoutError to work

Constant Summary collapse

OrbStackNotInstalled =

Alias error classes inside Errors namespace for tests that expect them there

::VagrantPlugins::OrbStack::OrbStackNotInstalled
OrbStackNotInstalledError =
OrbStackNotInstalled
OrbStackNotRunning =
::VagrantPlugins::OrbStack::OrbStackNotRunning
CommandExecutionError =
::VagrantPlugins::OrbStack::CommandExecutionError
CommandTimeoutError =
::VagrantPlugins::OrbStack::CommandTimeoutError
MachineNameCollisionError =
::VagrantPlugins::OrbStack::MachineNameCollisionError
SSHNotReady =
::VagrantPlugins::OrbStack::SSHNotReady
SSHConnectionFailed =
::VagrantPlugins::OrbStack::SSHConnectionFailed
OrbStackCLIError =

Alias for CLI errors

CommandExecutionError