Class: VagrantPlugins::OrbStack::Plugin

Inherits:
Object
  • Object
show all
Defined in:
lib/vagrant-orbstack/plugin.rb

Overview

OrbStack provider plugin for Vagrant.

This plugin enables OrbStack as a provider backend for Vagrant, allowing users to create and manage Linux development environments on macOS using OrbStack's high-performance virtualization.

Class Method Summary collapse

Class Method Details

.setup!Object

Setup I18n locale files for error messages



36
37
38
39
# File 'lib/vagrant-orbstack/plugin.rb', line 36

def self.setup!
  locale_path = Pathname.new(File.expand_path('../locales', __dir__))
  I18n.load_path << locale_path.join('en.yml') if locale_path.exist?
end